quantizationtools.QTargetMeasure
================================

.. abjad-lineage:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure

.. autoclass:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.beats
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.duration_in_ms
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.offset_in_ms
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.search_tree
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.tempo
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.time_signature
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.use_full_measure
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__eq__
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__format__
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__ne__
      ~abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.beats
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.offset_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.tempo
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.time_signature
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.use_full_measure
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.__repr__
   :noindex:
